@@ -16,7 +16,7 @@ from ondine_laser_control import laser
 print("Starting...")
 
 movement_distances = {"1": 0.1, "2": 1, "3": 10}
-movement_distance = None
+movement_distance = 0.1
 
 
 # from https://github.com/theosanderson/tube_checkout
@@ -70,6 +70,7 @@ def set_button_yellow(protocol_to_use: ProtocolContext):
 def set_button_as_kill_switch(protocol_to_use: ProtocolContext):
     global watcher_thread
     set_button_red(protocol_to_use)
+
     def button_watcher():
         while not threading.current_thread().stopped():
             time.sleep(0.1)
@@ -127,6 +128,7 @@ initial_offsets = laser.read_offsets_file()
 x_offset = initial_offsets['x']
 y_offset = initial_offsets['y']
 z_offset = initial_offsets['z']
+top_of_well = plate["A1"].top().point
 
 
 def set_movement_distance(distance):
@@ -138,7 +140,6 @@ def set_movement_distance(distance):
 def update_offset():
     global x_offset, y_offset, z_offset
     p = laserController.get_current_pos()
-    top_of_well = plate["A1"].top().point
     x_offset = p.x - top_of_well.x
     y_offset = p.y - top_of_well.y
     z_offset = p.z - laserController.z_abs_min - top_of_well.z
@@ -159,17 +160,29 @@ def save_offset():
 
 def show_or_exit(key):
     message.set_text("")
-    global movement_distance
+    global movement_distance, top_of_well
     if key in movement_distances.keys():
         set_movement_distance(movement_distances[key])
-    if key == "!":
+    if key in ("U", "u"):
+        top_of_well = plate["A1"].top().point
+        laserController.move_to_well(plate["A1"])
         laserController.move_z(plate["A1"].top(5).point.z)
-    if key == "@":
+
+    if key in ("I", "i"):
+        top_of_well = plate["A12"].top().point
+        laserController.move_to_well(plate["A12"])
         laserController.move_z(plate["A12"].top(5).point.z)
-    if key == "#":
-        laserController.move_z(plate["F12"].top(5).point.z)
-    if key == "$":
+
+    if key in ("O", "o"):
+        top_of_well = plate["F1"].top().point
+        laserController.move_to_well(plate["F1"])
+        laserController.move_z(plate["F1"].top(5).point.z)
+
+    if key in ("P", "p"):
+        top_of_well = plate["F12"].top().point
+        laserController.move_to_well(plate["F12"])
         laserController.move_z(plate["F12"].top(5).point.z)
+
     if key in ('h', 'H'):
         protocol.home()
 
@@ -179,10 +192,10 @@ def show_or_exit(key):
     if key in ('s', 'S'):
         save_offset()
 
-    if key in ('k', 'K', "shift up"):
+    if key == "shift up":
         laserController.move_relz(movement_distance)
 
-    if key in ('m', 'M', "shift down"):
+    if key == "shift down":
         laserController.move_relz(-movement_distance)
     if key == "up":
         laserController.move_rely(movement_distance)
@@ -210,8 +223,8 @@ keyboard = urwid.Text(f"""\
 KEYBOARD SHORTCUTS:
 Number keys - set movement distance: {num_key_expl}
 Arrow keys - move horizontally by movement distance
-k/m - move vertically up/down by movement distance
-s - save calibration (for A1 of tube A1 of slot '5')
+Shift + up and down Arrow keys - move vertically by movement distance
+s - save calibration 
 h - home
 q - exit
 """)
@@ -241,8 +254,6 @@ palette = [
     ('buttn', 'black', 'dark cyan'),
     ('buttnf', 'white', 'dark blue', 'bold'),
 ]
-
-set_movement_distance(0.1)
 update_pos()
 loop = urwid.MainLoop(frame, palette, unhandled_input=show_or_exit)
 loop.run()
